DisjointSetArrayU32

Struct DisjointSetArrayU32 

pub struct DisjointSetArrayU32<const SIZE: usize>(/* private fields */);

Implementations

Source

impl<const SIZE: usize> DisjointSetArrayU32<SIZE>

pub fn new() -> Self

Creates new disjoint set. Does not compile if SIZE too big:

use aph_disjoint_set::DisjointSetArrayU8;
let _: DisjointSetArrayU8<500> = DisjointSetArrayU8::new();
#[cfg(miri)] // Miri doesn't catch compile error because it doesn't evaluate code in such tests.
let _: u32 = 0u64;
pub fn initialize_inplace(memory: &mut MaybeUninit<Self>) -> &mut Self

Initializes some memory with default state of disjoint set and returns reference to it. Useful if you want hard guarantee that compiler doesn’t allocate some place on stack for temporary value during moves.

Does not compile if SIZE too big:

use core::mem::MaybeUninit;
use aph_disjoint_set::DisjointSetArrayU8;

let mut value: MaybeUninit<DisjointSetArrayU8<500>> = MaybeUninit::uninit();
DisjointSetArrayU8::initialize_inplace(&mut value);
#[cfg(miri)] // Miri doesn't catch compile error because it doesn't evaluate code in such tests.
let _: u32 = 0u64;
Example
use core::mem::MaybeUninit;
use aph_disjoint_set::DisjointSetArrayU8;

let mut value: MaybeUninit<DisjointSetArrayU8<10>> = MaybeUninit::uninit();
let djs = DisjointSetArrayU8::initialize_inplace(&mut value);
djs.union(9, 1);
assert!(djs.is_united(1, 9));
Source

impl<const SIZE: usize> DisjointSetArrayU32<SIZE>

pub fn get_root(&mut self, idx: usize) -> Root

Same as DisjointSet::get_root.

Panics

If index is out of bounds.

pub fn union(&mut self, idx0: usize, idx1: usize) -> UnionResult

Same as DisjointSet::union.

Panics

If any index is out of bounds.

pub fn is_united(&mut self, idx0: usize, idx1: usize) -> bool

Same as DisjointSet::is_united.

Panics

If any index is out of bounds.

pub fn detach(&mut self, idx: usize)

Same as DisjointSet::detach.

Panics

If index is out of bounds.

pub fn split_at(&mut self, split_idx: usize) -> (ChunkMut<'_>, ChunkMut<'_>)

pub fn make_ro_view(&mut self) -> DisjointSetRoView<'_>

pub fn into_readonly(self) -> RoDisjointSetArrayU32<SIZE>

pub fn compress_paths(&mut self)

pub fn reset(&mut self)